package com.rjconsultores.ventaboletos.relatorios.impl;

import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Timestamp;
import java.util.Date;
import java.util.Map;

import com.rjconsultores.ventaboletos.relatorios.utilitarios.ArrayCustomDataSourceRelatorio;
import com.rjconsultores.ventaboletos.relatorios.utilitarios.Relatorio;
import com.rjconsultores.ventaboletos.utilerias.DateUtil;
import com.rjconsultores.ventaboletos.utilerias.MoneyHelper;
import com.rjconsultores.ventaboletos.web.utilerias.NamedParameterStatement;

public class RelatorioIntegracaoAntiFraude extends Relatorio {

	public RelatorioIntegracaoAntiFraude(Map<String, Object> parametros, Connection conexao){
		super(parametros, conexao);
	}

	@Override
	protected void processaParametros() throws Exception {
		setCustomDataSource(new ArrayCustomDataSource(this));
	}
	
	private final class ArrayCustomDataSource extends ArrayCustomDataSourceRelatorio {

		public ArrayCustomDataSource(Relatorio relatorio) throws Exception {
			super(relatorio);
		}

		@Override
		protected void getSql(StringBuilder instrucaoSql, Map<String, Object> parametros) {
			instrucaoSql.append("SELECT TK.KONDUTO_ID ID_KONDUTO, ");
			instrucaoSql.append("LPAD(CASE WHEN CLI.TIPOIDENTIFICAUNO_ID = 2 THEN ");
			instrucaoSql.append("    NUMIDENTIFICAUNO ");
			instrucaoSql.append("WHEN CLI.TIPOIDENTIFICADOS_ID = 2 THEN ");
			instrucaoSql.append("    NUMIDENTIFICADOS  ");
			instrucaoSql.append("END, 11, '0') CPF_COMPRADOR, CLI.NOMBCLIENTE NOME_COMPRADOR, ");
			instrucaoSql.append("TO_CHAR(B.FECHORVENTA, 'DD/MM/YYYY') DATA_COMPRA,  ");
			instrucaoSql.append("TO_CHAR(B.FECHORVENTA, 'HH24:MI') HORA_COMPRA,  ");
			instrucaoSql.append("CT.NSU, CT.NUMAUTORIZACION AUTORIZACAO, ");
			instrucaoSql.append("COALESCE(B.PRECIOPAGADO,0) + COALESCE(B.IMPORTETAXAEMBARQUE,0) +  ");
			instrucaoSql.append("COALESCE(B.IMPORTESEGURO,0) + COALESCE(B.IMPORTEPEDAGIO,0) + COALESCE(B.IMPORTEOUTROS,0) AS VALOR_TOTAL, ");
			instrucaoSql.append("B.CORRIDA_ID SERVICO, ");
			instrucaoSql.append("TO_CHAR(B.FECHORVIAJE, 'DD/MM/YYYY') DATA_VIAGEM,  ");
			instrucaoSql.append("TO_CHAR(B.FECHORVIAJE, 'HH24:MI') HORA_VIAGEM,  ");
			instrucaoSql.append("PO.DESCPARADA ORIGEM, PD.DESCPARADA DESTINO, ");
			instrucaoSql.append("B.NUMFOLIOSISTEMA BILHETE, ");
			instrucaoSql.append("B.NUMASIENTO POLTRONA, ");
			instrucaoSql.append("B.NOMBPASAJERO PASSAGEIRO ");
			instrucaoSql.append("FROM BOLETO B ");
			instrucaoSql.append("INNER JOIN TRANSACAO_KONDUTO TK ON B.BOLETO_ID = TK.BOLETO_ID ");
			instrucaoSql.append("LEFT JOIN CLIENTE CLI ON B.CLIENTECOMPRADOR_ID = CLI.CLIENTE_ID ");
			instrucaoSql.append("LEFT JOIN CAJA C ON B.BOLETO_ID = C.TRANSACAO_ID ");
			instrucaoSql.append("LEFT JOIN CAJA_DET_PAGO CDP ON C.CAJA_ID = CDP.CAJA_ID ");
			instrucaoSql.append("LEFT JOIN CAJA_TARJETA CT ON CDP.CAJADETPAGO_ID = CT.CAJADETPAGO_ID ");
			instrucaoSql.append("LEFT JOIN PARADA PO ON B.ORIGEN_ID = PO.PARADA_ID ");
			instrucaoSql.append("LEFT JOIN PARADA PD ON B.DESTINO_ID = PD.PARADA_ID ");
			instrucaoSql.append("WHERE B.FECHORVENTA BETWEEN :dtInicial AND :dtFinal ");
			instrucaoSql.append("AND TK.STATUSTRANSACAO IN("+parametros.get("statusKondutoId").toString()+") ");
			instrucaoSql.append("AND B.MARCA_ID = :empresaId ");
		}

		@Override
		protected void populaValoresDataResult(Map<String, Object> dataResult, ResultSet resultSet) throws SQLException {
			dataResult.put("ID_KONDUTO", resultSet.getString("ID_KONDUTO"));
			dataResult.put("CPF_COMPRADOR", resultSet.getString("CPF_COMPRADOR"));
			dataResult.put("NOME_COMPRADOR", resultSet.getString("NOME_COMPRADOR"));
			dataResult.put("DATA_COMPRA", resultSet.getString("DATA_COMPRA"));
			dataResult.put("HORA_COMPRA", resultSet.getString("HORA_COMPRA"));
			dataResult.put("NSU", resultSet.getString("NSU"));
			dataResult.put("AUTORIZACAO", resultSet.getString("AUTORIZACAO"));
			dataResult.put("VALOR_TOTAL", MoneyHelper.instanciar(resultSet.getBigDecimal("VALOR_TOTAL")));
			dataResult.put("SERVICO", resultSet.getString("SERVICO"));
			dataResult.put("DATA_VIAGEM", resultSet.getString("DATA_VIAGEM"));
			dataResult.put("HORA_VIAGEM", resultSet.getString("HORA_VIAGEM"));
			dataResult.put("ORIGEM", resultSet.getString("ORIGEM"));
			dataResult.put("DESTINO", resultSet.getString("DESTINO"));
			dataResult.put("BILHETE", resultSet.getString("BILHETE"));
			dataResult.put("POLTRONA", resultSet.getString("POLTRONA"));
			dataResult.put("PASSAGEIRO", resultSet.getString("PASSAGEIRO"));
		}

		@Override
		protected void configuraParametrosConsultaSql(Map<String, Object> parametros, NamedParameterStatement stmt) throws SQLException {
			stmt.setTimestamp("dtInicial", new Timestamp(DateUtil.inicioFecha((Date) parametros.get("dtInicial")).getTime()));
			stmt.setTimestamp("dtFinal", new Timestamp(DateUtil.fimFecha((Date) parametros.get("dtFinal")).getTime()));
			stmt.setObject("empresaId", parametros.get("empresaId"));
		}
		
	}
}
