package com.rjconsultores.ventaboletos.web.gui.controladores.relatorios.integracaoantifraude;

import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.zkoss.util.resource.Labels;
import org.zkoss.zk.ui.event.EventListener;

import com.rjconsultores.ventaboletos.entidad.Empresa;
import com.rjconsultores.ventaboletos.relatorios.impl.RelatorioIntegracaoAntiFraude;
import com.rjconsultores.ventaboletos.relatorios.utilitarios.Relatorio;
import com.rjconsultores.ventaboletos.utils.FormataUtil;
import com.rjconsultores.ventaboletos.web.utilerias.EventListenerExecutarRelatorio;

public class EventListenerExecutarRelatorioIntegracaoAntiFraude extends EventListenerExecutarRelatorio<RelatorioIntegracaoAntiFraudeController> implements EventListener {
	
	private static final String MASCARA_DATA_COMPLETA = "dd/MM/yyyy hh:mm:ss";

	public EventListenerExecutarRelatorioIntegracaoAntiFraude(RelatorioIntegracaoAntiFraudeController controller) {
		super(controller);
	}

	@Override
	protected String getTituloRelatorio() {
		return RelatorioIntegracaoAntiFraudeController.TITULO_RELATORIO;
	}

	@Override
	protected boolean filtrosValidos(RelatorioIntegracaoAntiFraudeController controller) {
		return new ValidaFormRelatorioIntegracaoAntiFraude(controller).isValido();
	}

	@Override
	protected Relatorio configuraRelatorio(RelatorioIntegracaoAntiFraudeController controller) throws SQLException {
		return new RelatorioIntegracaoAntiFraude(getParametros(), controller.getDataSource().getConnection());
	}

	private Map<String, Object> getParametros() {
		Map<String, Object> parametros = new HashMap<String, Object>();
		
		parametros.put("NOME_RELATORIO", Labels.getLabel(getTituloRelatorio()));
		parametros.put("dtInicial", getController().getDtInicial().getValue());
		parametros.put("dtFinal", getController().getDtFinal().getValue());
		parametros.put("periodo", obtemPeriodo());
		Empresa empresa = getController().getCmbEmpresa().getSelecteObject(Empresa.class);
		parametros.put("empresaId", empresa.getEmpresaId());
		parametros.put("empresa", empresa.getNombempresa());
		List<StringBuilder> statusKondutoSelecionados = obtemIdsEDescricaoStatusKondutoSelecionados();
		parametros.put("statusKondutoId", statusKondutoSelecionados.get(0).toString());
		parametros.put("statusKonduto", statusKondutoSelecionados.get(1).toString());
		
		return parametros;
	}

	private List<StringBuilder> obtemIdsEDescricaoStatusKondutoSelecionados() {
		StringBuilder idsKonduto = new StringBuilder();
		StringBuilder descricaoKonduto = new StringBuilder();
		List<Object> statusKondutoSelecionados = getController().getKondutoList().getItensSelecionados();
		populaKondutoSelecionados(idsKonduto, descricaoKonduto, statusKondutoSelecionados);
		ArrayList<StringBuilder> kondutosSelecionados = new ArrayList<StringBuilder>();
		kondutosSelecionados.add(idsKonduto);
		kondutosSelecionados.add(descricaoKonduto);
		return kondutosSelecionados;
	}

	private void populaKondutoSelecionados(StringBuilder idsKonduto, StringBuilder descricaoKonduto, List<Object> statusKondutoSelecionados) {
		for (int i = 0; i < statusKondutoSelecionados.size(); i++) {
			EStatusKonduto statusKonduto = (EStatusKonduto)statusKondutoSelecionados.get(i);
			idsKonduto.append("'"+statusKonduto.getId()+"'");
			descricaoKonduto.append(statusKonduto.getDescricao());
			if (i != statusKondutoSelecionados.size()-1) {
				idsKonduto.append(", ");
				descricaoKonduto.append(", ");
			}
		}
	}

	private String obtemPeriodo() {
		return FormataUtil.formataDataToString((Date)getController().getDtInicial().getValue(), "", MASCARA_DATA_COMPLETA)
				+" at "+FormataUtil.formataDataToString((Date)getController().getDtFinal().getValue(), "", MASCARA_DATA_COMPLETA);
	}

}
